delineate
=========
|Docs|_  |PyPI|_ |Git|_

.. |Docs| image:: https://readthedocs.org/projects/delineate/badge/?version=latest
.. _Docs: https://delineate.readthedocs.io/

.. |PyPI| image:: https://badge.fury.io/py/delineate.svg
.. _PyPI: https://pypi.org/project/delineate/

.. |Git| image:: https://github.com/cjw296/delineate/actions/workflows/ci.yml/badge.svg
.. _Git: https://github.com/cjw296/delineate

This package provides a command line tool to backup and export data from `Linear`__.

__ https://linear.app/
